@@ -33,9 +33,6 @@ from glob import glob
 from locale import getdefaultlocale
 
 from gi import require_version as gi_required_version
-gi_required_version('GtkSpell', '3.0')
-gi_required_version('Gtk', '3.0')
-
 from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import GdkPixbuf
@@ -43,10 +40,12 @@ from gi.repository import GdkPixbuf
 import db
 import gutils
 
+gi_required_version('Gtk', '3.0')
 try:
+    gi_required_version('GtkSpell', '3.0')
     from gi.repository import GtkSpell
     spell_support = 1
-except:
+except Exception:
     spell_support = 0
 
 log = logging.getLogger("Griffith")
@@ -310,7 +309,7 @@ def treeview(self):
                 columnsize = int(columnsize)
                 self.widgets['treeview'].get_column(currentcol).set_sizing(Gtk.TreeViewColumnSizing.FIXED)
                 self.widgets['treeview'].get_column(currentcol).set_fixed_width(columnsize)
-            except:
+            except Exception:
                 pass
             currentcol += 1
     # reflect saved column sorting
@@ -324,7 +323,7 @@ def treeview(self):
             else:
                 columnsortorder = Gtk.SortType.ASCENDING
             self.treemodel.set_sort_column_id(columnsortid, columnsortorder)
-    except:
+    except Exception:
         log.exception('')
     # add data to treeview
     self.total = self.db.session.query(db.Movie).count()
@@ -470,8 +469,8 @@ def movie_plugins(self):
 
     tmdbsimple_installed = True
     try:
-        import tmdbsimple
-    except:
+        pass
+    except Exception:
         tmdbsimple_installed = False
 
     self.plugins = gutils.read_plugins('PluginMovie',
@@ -528,7 +527,8 @@ def import_plugins(self):
 
     # glade
     glade_file = os.path.join(self.locations['glade'], 'import.ui')
-    get = lambda x: builder.get_object(x)
+    def get(x):
+        return builder.get_object(x)
     builder = Gtk.Builder()
     builder.set_translation_domain("griffith")
     builder.add_from_file(glade_file)
@@ -715,7 +715,6 @@ def extensions(self):
 
 
 def people_treeview(self, create=True):
-    row = None
     self.p_treemodel = Gtk.TreeStore(
         GObject.TYPE_STRING, GObject.TYPE_STRING, GObject.TYPE_STRING,
         GObject.TYPE_STRING)
@@ -904,7 +903,7 @@ def spellcheck(self):
                     self.notes_spell = GtkSpell.Checker.new()
                     self.notes_spell.set_language(self.config.get('lang', section='spell'))
                     self.notes_spell.attach(self.widgets['add']['notes'])
-                except:
+                except Exception:
                     spell_error = True
 
             if (self.config.get('plot', True, section='spell') is True
@@ -914,7 +913,7 @@ def spellcheck(self):
                     self.plot_spell.set_language(
                         self.config.get('lang', section='spell'))
                     self.plot_spell.attach(self.widgets['add']['plot'])
-                except:
+                except Exception:
                     spell_error = True
             if spell_error:
                 log.info('Dictionary not available. Spell check will be disabled.')
@@ -1197,7 +1196,7 @@ def create_tag_vbox(self, widget, tab):
 
 
 def remove_hbox(self, widget, tab):
-    number = len(widget.get_children()) - 1  # last box number
+    len(widget.get_children()) - 1  # last box number
     try:
         tab.pop()
         widget.remove(widget.get_children().pop())
