@@ -173,7 +173,7 @@ class SearchPlugin(movie.SearchMovie):
         tmp_pagecount = gutils.trim(tmp_pagemovie, 'Seiten (<b>', '</b>)')
         try:
             tmp_pagecountint = int(tmp_pagecount)
-        except:
+        except Exception:
             tmp_pagecountint = 1
         tmp_pagecountintcurrent = 1
         while (tmp_pagecountint > tmp_pagecountintcurrent and tmp_pagecountintcurrent < 5):
@@ -189,7 +189,7 @@ class SearchPlugin(movie.SearchMovie):
         elements[0] = None
         for index in range(1, len(elements), 2):
             element = elements[index + 1]
-            if element != None:
+            if element is not None:
                 if elements[index] == '/datenbank/medien/blu-ray/':
                     medium = 'Blu-Ray'
                     self.ids.append('blu-ray/' + gutils.before(element,'"'))
